import os
from pathlib import Path

class IdentificaDiretorio:
    def localizaDir(pastaBusca):
        lista = ['c','a','b','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','x']
        for i in lista:
            if os.path.isdir( i +':'):
                local =  i +':/'

        diretorio = Path(local)
        arquivos = diretorio.glob('**/{}'.format(pastaBusca))

        for i in arquivos:
            if 'Business Intelligence' in str(i):
                output = str(i)
            elif 'Schedules Products' in str(i):
                script = str(i)

        return output, script


from setuptools import setup, find_packages

VERSION = '0.1.0' 
DESCRIPTION = 'Pacote Utilizado para Localizar o Diretorio de Determinada Pasta'
LONG_DESCRIPTION = 'Pacote Utilizado para Localizar o Diretorio de Determinada Pasta'

# Setting up
setup(
       # 'name' deve corresponder ao nome da pasta 'verysimplemodule'
        name="directorySearchCogna", 
        version=VERSION,
        author="Marco Rocha",
        author_email="<marco.rocha2@outlook.com>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=[''],         
        keywords=['python', 'first package'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
        ]
)